pub fn parse(content: &str) -> (FrontMatter, String)Expand description
Parse ---\nkey: value\n---\nbody... into (FrontMatter, body).
If no frontmatter delimiters are found, returns default metadata and the full content as body.
pub fn parse(content: &str) -> (FrontMatter, String)Parse ---\nkey: value\n---\nbody... into (FrontMatter, body).
If no frontmatter delimiters are found, returns default metadata and the full content as body.